@@ -60,7 +60,7 @@ import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 
 /**
  * This is an abstract class for all common attributes and methods of database related command line tools
- * 
+ *
  * @author d7
  */
 public abstract class DatabaseAbstraction extends UtilAbstraction {
@@ -117,6 +117,8 @@ public abstract class DatabaseAbstraction extends UtilAbstraction {
 
     protected final static String OPT_NAME_IS_MASTER_LONG = "master";
 
+    protected final static String OPT_NAME_SCHEMA_LONG = "schema";
+
     protected CLIOption databaseIdOption = null;
 
     protected CLIOption databaseUsernameOption = null;
@@ -143,9 +145,10 @@ public abstract class DatabaseAbstraction extends UtilAbstraction {
 
     protected CLIOption poolMaxOption = null;
 
+    protected CLIOption schemaOption = null;
+
     // Needed for right error output
     protected String dbid = null;
-
     protected String dbname = null;
 
     protected void parseAndSetDatabaseID(final AdminParser parser, final Database db) {
@@ -162,6 +165,13 @@ public abstract class DatabaseAbstraction extends UtilAbstraction {
         }
     }
 
+    protected void parseAndSetSchema(final AdminParser parser, final Database db) {
+        String schema = (String) parser.getOptionValue(this.schemaOption);
+        if (null != schema) {
+            db.setScheme(schema);
+        }
+    }
+
     private void parseAndSetHostname(final AdminParser parser, final Database db) throws InvalidDataException {
         String hostname = (String) parser.getOptionValue(this.hostnameOption);
         if (null != hostname) {
@@ -271,6 +281,10 @@ public abstract class DatabaseAbstraction extends UtilAbstraction {
             NeededQuadState.eitheror);
     }
 
+    protected void setDatabaseSchemaOption(final AdminParser parser) {
+        this.schemaOption = setLongOpt(parser, OPT_NAME_SCHEMA_LONG, "The optional schema name of the database.", true, false);
+    }
+
     protected void setDatabasePoolMaxOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
             this.poolMaxOption = setShortLongOptWithDefault(
