@@ -61,7 +61,7 @@ import com.openexchange.tools.sql.DBUtils;
  *
  * @author cutmasta
  */
-public class DataFetcherMysql implements DataFetcher{
+public class DataFetcherMysql implements DataFetcher {
 
     private final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(DataFetcherMysql.class);
 
@@ -75,12 +75,11 @@ public class DataFetcherMysql implements DataFetcher{
     private DatabaseMetaData dbmetadata = null;
 
     @Override
-    public String getCatalogName(){
+    public String getCatalogName() {
         return this.catalogname;
     }
 
-    public DataFetcherMysql() {
-    }
+    public DataFetcherMysql() {}
 
     @Override
     public Connection getDbConnection() {
@@ -88,7 +87,7 @@ public class DataFetcherMysql implements DataFetcher{
     }
 
     @Override
-    public void setDbConnection(Connection dbConnection,String catalog_name) throws SQLException {
+    public void setDbConnection(Connection dbConnection, String catalog_name) throws SQLException {
         this.dbConnection = dbConnection;
         this.dbConnection.setCatalog(catalog_name);
         this.catalogname = catalog_name;
@@ -105,46 +104,45 @@ public class DataFetcherMysql implements DataFetcher{
     }
 
     @Override
-    public int getColumnMatchType(){
+    public int getColumnMatchType() {
         return this.criteriaType;
     }
 
     @Override
-    public Object getColumnMatchObject(){
+    public Object getColumnMatchObject() {
         return this.criteriaMatch;
     }
 
     @Override
-    public void setColumnMatchObject(Object match_obj,int match_type){
+    public void setColumnMatchObject(Object match_obj, int match_type) {
         this.criteriaType = match_type;
         this.criteriaMatch = match_obj;
     }
 
     @Override
-    public TableObject getDataForTable(TableObject to) throws SQLException{
+    public TableObject getDataForTable(TableObject to) throws SQLException {
 
         Vector<TableColumnObject> column_objects = to.getColumns();
         // build the statement string
         StringBuilder sb = new StringBuilder();
         sb.append("SELECT ");
-        for(int a = 0;a<column_objects.size();a++){
+        for (int a = 0; a < column_objects.size(); a++) {
             TableColumnObject tco = column_objects.get(a);
-            sb.append(""+tco.getName()+",");
+            sb.append("" + tco.getName() + ",");
         }
-        sb.delete(sb.length()-1,sb.length());
-        sb.append(" FROM "+to.getName()+" WHERE "+getMatchingColumn()+" = ?");
-
+        sb.delete(sb.length() - 1, sb.length());
+        sb.append(" FROM " + to.getName() + " WHERE " + getMatchingColumn() + " = ?");
 
         // fetch data from table
         PreparedStatement prep = null;
-        try{
+        try {
             prep = this.dbConnection.prepareStatement(sb.toString());
-            prep.setObject(1,getColumnMatchObject(),getColumnMatchType());
+            prep.setObject(1, getColumnMatchObject(), getColumnMatchType());
             log.debug("######## {}", sb);
             ResultSet rs = prep.executeQuery();
-            while(rs.next()){
+            while (rs.next()) {
                 TableRowObject tro = new TableRowObject();
-                for(int b = 0;b<column_objects.size();b++){
+                for (int b = 0; b < column_objects.size(); b++) {
                     TableColumnObject tco = column_objects.get(b);
                     Object o = rs.getObject(tco.getName());
 
@@ -160,29 +158,27 @@ public class DataFetcherMysql implements DataFetcher{
             }
             rs.close();
             prep.close();
-        }finally{
+        } finally {
             try {
-                if(prep!=null){
+                if (prep != null) {
                     prep.close();
                 }
             } catch (Exception e) {
-                log.error("Error closing statement",e);
+                log.error("Error closing statement", e);
             }
         }
 
         return to;
 
-
-//        if(to.getDataRowCount()>0){
-//            tableObjects.add(to);
-//            //log.debug("{} {}", to.getName(), to.getDataRowCount());
-//        }
-
+        //        if(to.getDataRowCount()>0){
+        //            tableObjects.add(to);
+        //            //log.debug("{} {}", to.getName(), to.getDataRowCount());
+        //        }
 
     }
 
     @Override
-    public Vector<TableObject> fetchTableObjects() throws SQLException{
+    public Vector<TableObject> fetchTableObjects() throws SQLException {
         tableObjects = new Vector<TableObject>();
 
         dbmetadata = dbConnection.getMetaData();
@@ -196,26 +192,29 @@ public class DataFetcherMysql implements DataFetcher{
                 to = new TableObject();
                 to.setName(table_name);
                 // fetch all columns from table and see if it contains matching column
-                ResultSet columns_res = dbmetadata.getColumns(getCatalogName(), null, table_name, null);
-                boolean table_matches = false;
-                while (columns_res.next()) {
+                ResultSet columns_res = null;
+                try {
+                    columns_res = dbmetadata.getColumns(getCatalogName(), null, table_name, null);
+                    boolean table_matches = false;
+                    while (columns_res.next()) {
+                        TableColumnObject tco = new TableColumnObject();
+                        String column_name = columns_res.getString("COLUMN_NAME");
+                        tco.setName(column_name);
+                        tco.setType(columns_res.getInt("DATA_TYPE"));
+                        tco.setColumnSize(columns_res.getInt("COLUMN_SIZE"));
 
-                    TableColumnObject tco = new TableColumnObject();
-                    String column_name = columns_res.getString("COLUMN_NAME");
-                    tco.setName(column_name);
-                    tco.setType(columns_res.getInt("DATA_TYPE"));
-                    tco.setColumnSize(columns_res.getInt("COLUMN_SIZE"));
-
-                    // if table has our ciriteria column, we should fetch data from it
-                    if (column_name.equals(getMatchingColumn())) {
-                        table_matches = true;
+                        // if table has our ciriteria column, we should fetch data from it
+                        if (column_name.equals(getMatchingColumn())) {
+                            table_matches = true;
+                        }
+                        // add column to table
+                        to.addColumn(tco);
                     }
-                    // add column to table
-                    to.addColumn(tco);
-                }
-                columns_res.close();
-                if (table_matches) {
-                    tableObjects.add(to);
+                    if (table_matches) {
+                        tableObjects.add(to);
+                    }
+                } finally {
+                    DBUtils.closeSQLStuff(columns_res);
                 }
             }
             log.debug("####### Found -> {} tables", tableObjects.size());
@@ -226,31 +225,31 @@ public class DataFetcherMysql implements DataFetcher{
         return tableObjects;
     }
 
-//    TODO: This function is for testing purposes only, and may be uncommented then
-//    private void printTables(Vector tablelist) {
-//        final StringBuilder sb = new StringBuilder();
-//        for(int a = 0;a<tablelist.size();a++){
-//            TableObject to = (TableObject)tablelist.get(a);
-//            sb.append("Table: ");
-//            sb.append(to.getName());
-//            sb.append(", cross references: ");
-//            Iterator iter = to.getCrossReferenceTables();
-//            while (iter.hasNext()) {
-//                sb.append(iter.next());
-//                sb.append(',');
-//            }
-//            sb.deleteCharAt(sb.length() - 1);
-//            sb.append(", referenced by: ");
-//            iter = to.getReferencedByTables();
-//            while (iter.hasNext()) {
-//                sb.append(iter.next());
-//                sb.append(',');
-//            }
-//            sb.deleteCharAt(sb.length() - 1);
-//            sb.append('\n');
-//        }
-//        log.error(sb.toString());
-//    }
+    //    TODO: This function is for testing purposes only, and may be uncommented then
+    //    private void printTables(Vector tablelist) {
+    //        final StringBuilder sb = new StringBuilder();
+    //        for(int a = 0;a<tablelist.size();a++){
+    //            TableObject to = (TableObject)tablelist.get(a);
+    //            sb.append("Table: ");
+    //            sb.append(to.getName());
+    //            sb.append(", cross references: ");
+    //            Iterator iter = to.getCrossReferenceTables();
+    //            while (iter.hasNext()) {
+    //                sb.append(iter.next());
+    //                sb.append(',');
+    //            }
+    //            sb.deleteCharAt(sb.length() - 1);
+    //            sb.append(", referenced by: ");
+    //            iter = to.getReferencedByTables();
+    //            while (iter.hasNext()) {
+    //                sb.append(iter.next());
+    //                sb.append(',');
+    //            }
+    //            sb.deleteCharAt(sb.length() - 1);
+    //            sb.append('\n');
+    //        }
+    //        log.error(sb.toString());
+    //    }
 
     @Override
     public Vector<TableObject> sortTableObjects() throws SQLException {
@@ -261,43 +260,45 @@ public class DataFetcherMysql implements DataFetcher{
 
     }
 
-
     /**
      * Finds references for each table
      */
-    private void findReferences() throws SQLException{
-        for(int v = 0;v<tableObjects.size();v++){
+    private void findReferences() throws SQLException {
+        for (int v = 0; v < tableObjects.size(); v++) {
             TableObject to = tableObjects.get(v);
             // get references from this table to another
             String table_name = to.getName();
             //ResultSet table_references = dbmetadata.getCrossReference("%",null,table_name,getCatalogName(),null,getCatalogName());
-            ResultSet table_references = dbmetadata.getImportedKeys(getCatalogName(),null,table_name);
-            log.debug("Table {} has pk reference to table-column:", table_name);
-            while(table_references.next()){
-                String pk = table_references.getString("PKTABLE_NAME");
-                String pkc = table_references.getString("PKCOLUMN_NAME");
-                log.debug("--> Table: {} column ->{}", pk, pkc);
-                to.addCrossReferenceTable(pk);
-                int pos_in_list = tableListContainsObject(pk);
-                if(pos_in_list!=-1){
-                    log.debug("Found referenced by {}<->{}->{}", table_name, pk, pkc);
-                    TableObject edit_me = tableObjects.get(pos_in_list);
-                    edit_me.addReferencedBy(table_name);
+            ResultSet table_references = null;
+            try {
+                table_references = dbmetadata.getImportedKeys(getCatalogName(), null, table_name);
+                log.debug("Table {} has pk reference to table-column:", table_name);
+                while (table_references.next()) {
+                    String pk = table_references.getString("PKTABLE_NAME");
+                    String pkc = table_references.getString("PKCOLUMN_NAME");
+                    log.debug("--> Table: {} column ->{}", pk, pkc);
+                    to.addCrossReferenceTable(pk);
+                    int pos_in_list = tableListContainsObject(pk);
+                    if (pos_in_list != -1) {
+                        log.debug("Found referenced by {}<->{}->{}", table_name, pk, pkc);
+                        TableObject edit_me = tableObjects.get(pos_in_list);
+                        edit_me.addReferencedBy(table_name);
+                    }
                 }
+            } finally {
+                DBUtils.closeSQLStuff(table_references);
             }
-            table_references.close();
         }
     }
 
-
     /**
      * Returns -1 if not found else the position in the Vector where the object is located.
      */
-    private int tableListContainsObject(String table_name){
+    private int tableListContainsObject(String table_name) {
         int found_at_position = -1;
-        for(int v = 0;v<tableObjects.size();v++){
+        for (int v = 0; v < tableObjects.size(); v++) {
             TableObject to = tableObjects.get(v);
-            if(to.getName().equals(table_name)){
+            if (to.getName().equals(table_name)) {
                 found_at_position = v;
             }
         }
@@ -312,14 +313,14 @@ public class DataFetcherMysql implements DataFetcher{
 
         // now sort the table with a topological sort mech :)
         // work with the unsorted vector
-        while(unsorted.size()>0){
-            for(int a = 0;a<unsorted.size();a++){
+        while (unsorted.size() > 0) {
+            for (int a = 0; a < unsorted.size(); a++) {
                 TableObject to = unsorted.get(a);
-                if(!to.hasCrossReferences()){
+                if (!to.hasCrossReferences()) {
                     //log.error("removing {}", to.getName());
                     nasty_order.add(to);
                     // remove object from list and sort the references new
-                    removeAndSortNew(unsorted,to);
+                    removeAndSortNew(unsorted, to);
                     a--;
                 }
             }
@@ -334,9 +335,9 @@ public class DataFetcherMysql implements DataFetcher{
      * remove no more needed element from list and remove the reference to removed element
      * so that a new element exists which has now references.
      */
-    private void removeAndSortNew(Vector<TableObject> v,TableObject to){
+    private void removeAndSortNew(Vector<TableObject> v, TableObject to) {
         v.remove(to);
-        for(int i = 0;i<v.size();i++){
+        for (int i = 0; i < v.size(); i++) {
             TableObject tob = v.get(i);
             tob.removeCrossReferenceTable(to.getName());
         }
