@@ -60,8 +60,10 @@ import com.openexchange.admin.rmi.dataobjects.Group;
 import com.openexchange.admin.rmi.dataobjects.Resource;
 import com.openexchange.admin.rmi.dataobjects.Server;
 import com.openexchange.admin.rmi.dataobjects.User;
+import com.openexchange.admin.rmi.exceptions.DatabaseUpdateException;
 import com.openexchange.admin.rmi.exceptions.EnforceableDataObjectException;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
+import com.openexchange.admin.rmi.exceptions.NoSuchContextException;
 import com.openexchange.admin.rmi.exceptions.NoSuchGroupException;
 import com.openexchange.admin.rmi.exceptions.NoSuchObjectException;
 import com.openexchange.admin.rmi.exceptions.NoSuchResourceException;
@@ -92,7 +94,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Creates a new instance implementing the group storage interface.
-     * 
+     *
      * @return an instance implementing the group storage interface.
      */
     public static OXToolStorageInterface getInstance() {
@@ -111,7 +113,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Checks if given domain is used as mail address of any group in given context.
-     * 
+     *
      * @param domain
      * @return Groups which use this domain.null if no group uses this domain.
      * @throws StorageException
@@ -120,7 +122,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Checks if given domain is used as mail address of any resource in given context.
-     * 
+     *
      * @param domain
      * @return Resources which use this domain. null if no resource uses this domain.
      * @throws StorageException
@@ -129,7 +131,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Checks if given domain is used as alias or primary mail address of any user in given context.
-     * 
+     *
      * @param domain
      * @return Users which use this domain. null if no user uses this domain.
      * @throws StorageException
@@ -137,7 +139,7 @@ public abstract class OXToolStorageInterface {
     public abstract User[] domainInUseByUser(final Context ctx, final String domain) throws StorageException;
 
     /**
-     * Although this method get's a context Object it will only look after the cid
+     * Although this method accepts a context Object it will only look after the context identifier
      *
      * @param ctx
      * @return
@@ -145,6 +147,17 @@ public abstract class OXToolStorageInterface {
      */
     public abstract boolean existsContext(final Context ctx) throws StorageException;
 
+    /**
+     * Checks if specified context does exist in the registered server this provisioning is running in.
+     * <p>
+     * Although this method accepts a context Object it will only look after the context identifier
+     *
+     * @param ctx The context providing the context identifier
+     * @return <code>true</code> if context exists in server; otherwise <code>false</code> (either non-existing at all or resides in another server)
+     * @throws StorageException If checks fails
+     */
+    public abstract boolean existsContextInServer(final Context ctx) throws StorageException;
+
     public abstract boolean existsContextLoginMappings(final Context ctx) throws StorageException;
 
     public abstract boolean existsContextLoginMappings(final Context ctx, final Connection configdb_connection) throws StorageException;
@@ -160,7 +173,7 @@ public abstract class OXToolStorageInterface {
     /**
      * This method can be used to check if some group exists in a context. The connection is given to be able to check for groups that are
      * not committed yet.
-     * 
+     *
      * @param ctx Context.
      * @param con readable database connection.
      * @param id unique identifier of the group.
@@ -316,7 +329,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Checks via resource id and resource name if it already exists. Should be used in change method!
-     * 
+     *
      * @param ctx The context
      * @param res
      * @return
@@ -326,7 +339,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Checks if given name is already used for resource in given context!Should be used in create method!
-     * 
+     *
      * @param ctx The context
      * @param resourceName
      * @return
@@ -345,6 +358,30 @@ public abstract class OXToolStorageInterface {
      */
     public abstract boolean existsContextName(Context ctx) throws StorageException;
 
+    /**
+     * Checks context existence in server and if there is no other context with the same name
+     * <p>
+     * Should be used in change method!
+     *
+     * @param ctx The context
+     * @return <code>true</code> if denoted context currently holds a different name, otherwise <code>false</code> if name is equal
+     * @throws StorageException If existence check fails
+     */
+    public abstract boolean existsContextNameInServer(Context ctx) throws StorageException;
+
+    /**
+     * Checks context existence and if there is no other context with the same name
+     * <p>
+     * Should be used in change method!
+     *
+     * @param ctx The context
+     * @return <code>true</code> if denoted context currently holds a different name, otherwise <code>false</code> if name is equal
+     * @throws NoSuchContextException If such a context does not exist
+     * @throws InvalidDataException If another context already holds such a name
+     * @throws StorageException If existence check fails
+     */
+    public abstract boolean checkContextName(Context ctx) throws NoSuchContextException, InvalidDataException, StorageException;
+
     /**
      * Checks if given context name already exists!
      * <p>
@@ -356,6 +393,15 @@ public abstract class OXToolStorageInterface {
      */
     public abstract boolean existsContextName(final String contextName) throws StorageException;
 
+    /**
+     * Checks if given context name exists in the registered server this provisioning node is running in.
+     *
+     * @param contextName The context name
+     * @return <code>true</code> if such a context does exist; otherwise <code>false</code> (either non-existing at all or resides in another server)
+     * @throws StorageException If existence check fails
+     */
+    public abstract boolean existsContextNameInServer(final String contextName) throws StorageException;
+
     public abstract int getAdminForContext(final Context ctx, final Connection con) throws StorageException;
 
     public abstract int getAdminForContext(final Context ctx) throws StorageException;
@@ -374,6 +420,24 @@ public abstract class OXToolStorageInterface {
      */
     public abstract int getDatabaseIDByDatabaseSchema(String schemaName) throws StorageException, NoSuchObjectException;
 
+    /**
+     * Gets the database schema for specified context.
+     *
+     * @param contextId The context identifier
+     * @return The database schema
+     * @throws StorageException If database cannot be loaded
+     * @throws NoSuchObjectException If there is no such database schema
+     */
+    public abstract Database getSchemaByContextId(int contextId) throws StorageException, NoSuchObjectException;
+
+    /**
+     * Generates an appropriate {@link DatabaseUpdateException} for specified context.
+     *
+     * @param contextId The context identifier
+     * @return The <code>DatabaseUpdateException</code> instance
+     */
+    public abstract DatabaseUpdateException generateDatabaseUpdateException(int contextId);
+
     /**
      * Checks whether all contexts of the given db share the same write pool ID or not.
      *
@@ -386,7 +450,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Load database information with the given identifier.
-     * 
+     *
      * @param id the identifier of the database. It must be the identifier of the master.
      * @return the database information with the given identifier.
      * @throws StorageException if the database with the given identifier does not exist or a problem occurs when loading it.
@@ -468,6 +532,22 @@ public abstract class OXToolStorageInterface {
 
     public abstract boolean schemaBeingLockedOrNeedsUpdate(final int writePoolId, final String schema) throws StorageException;
 
+    /**
+     * Lists all schemas in databases that are either locked (currently marked as being updated) or needing an update.
+     *
+     * @return All such schemas as a list with length of 3; first element contains schemas needing an update, the second those schemas currently marked for being updated, and the third providing outdated updating schemas
+     * @throws StorageException If such schemas cannot be returned
+     */
+    public abstract List<List<Database>> listSchemasBeingLockedOrNeedsUpdate() throws StorageException;
+
+    /**
+     * Unblocks specified database schema or all schemas associated with specified database inc ase no schema name is given.
+     *
+     * @return The list of unblocked database schemas
+     * @throws StorageException If unblocking fails
+     */
+    public abstract List<Database> unblockDatabaseSchema(Database db) throws StorageException;
+
     public abstract boolean serverInUse(final int server_id) throws StorageException;
 
     public abstract void setUserSettingMailBit(final Context ctx, final User user, final int bit, final Connection con) throws StorageException;
@@ -494,7 +574,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Verifies whether the specified user is the owner of a master filestore and other users are using this filestore
-     * 
+     *
      * @param context The context
      * @param userId The user identifier
      * @return true if the user is a master filestore owner AND other users are using this filestore; false otherwise
@@ -504,7 +584,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Fetches the slave users of the master filestore
-     * 
+     *
      * @param context
      * @param userId
      * @return
@@ -514,7 +594,7 @@ public abstract class OXToolStorageInterface {
 
     /**
      * Determines whether the specified context is the last one on the database schema
-     * 
+     *
      * @param context The context
      * @return true if the specified context is the last one on the database schema; false otherwise
      * @throws StorageException if a problem occurs on the storage layer.
