@@ -59,16 +59,26 @@ public interface OXAdminPoolInterface {
 
     void setService(DatabaseService service);
 
+    @Deprecated
     Connection getConnectionForConfigDB() throws PoolException;
 
+    Connection getWriteConnectionForConfigDB() throws PoolException;
+
+    Connection getReadConnectionForConfigDB() throws PoolException;
+
     Connection getConnectionForContext(int contextId) throws PoolException;
 
     Connection getConnectionForContextNoTimeout(int contextId) throws PoolException;
 
     Connection getConnection(int poolId, String schema) throws PoolException;
 
+    @Deprecated
     boolean pushConnectionForConfigDB(Connection con) throws PoolException;
 
+    boolean pushWriteConnectionForConfigDB(Connection con) throws PoolException;
+
+    boolean pushReadConnectionForConfigDB(Connection con) throws PoolException;
+
     boolean pushConnectionForContext(int contextId, Connection con) throws PoolException;
 
     boolean pushConnectionForContextAfterReading(int contextId, Connection con) throws PoolException;
